@@ -62,7 +62,7 @@ pub fn safe_clone_config(config: &ValidatorConfig) -> ValidatorConfig {
         accounts_shrink_ratio: config.accounts_shrink_ratio,
         accounts_db_config: config.accounts_db_config.clone(),
         wait_to_vote_slot: config.wait_to_vote_slot,
-        shred_storage_type: config.shred_storage_type.clone(),
+        blockstore_advanced_options: config.blockstore_advanced_options.clone(),
     }
 }
 
